@@ -9,16 +9,11 @@ import operator
 
 from typing import Optional
 
-try:
-    from importlib import metadata  # type: ignore
-except ImportError:
-    import importlib_metadata as metadata  # type: ignore
+import importlib_metadata as metadata
 
 from . import credentials, errors, util
 from .util import properties
 
-__metaclass__ = type
-
 log = logging.getLogger(__name__)
 
 
@@ -46,6 +41,9 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     this interface.
     """
 
+    def __init__(self):
+        self.set_properties_from_env()
+
     # @abc.abstractproperty
     def priority(cls):
         """
@@ -68,7 +66,7 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     def viable(cls):
         with errors.ExceptionRaisedContext() as exc:
             cls.priority
-        return not bool(exc)
+        return not exc
 
     @classmethod
     def get_viable_backends(cls):
@@ -96,27 +94,27 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
         )
 
     @abc.abstractmethod
-    def get_password(self, service, username) -> Optional[str]:
+    def get_password(self, service: str, username: str) -> Optional[str]:
         """Get password of the username for the service"""
         return None
 
     @abc.abstractmethod
-    def set_password(self, service, username, password):
+    def set_password(self, service: str, username: str, password: str) -> None:
         """Set password for the username of the service.
 
         If the backend cannot store passwords, raise
-        NotImplementedError.
+        PasswordSetError.
         """
         raise errors.PasswordSetError("reason")
 
     # for backward-compatibility, don't require a backend to implement
     #  delete_password
     # @abc.abstractmethod
-    def delete_password(self, service, username):
+    def delete_password(self, service: str, username: str) -> None:
         """Delete the password for the username of the service.
 
-        If the backend cannot store passwords, raise
-        NotImplementedError.
+        If the backend cannot delete passwords, raise
+        PasswordDeleteError.
         """
         raise errors.PasswordDeleteError("reason")
 
@@ -124,7 +122,9 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     #  get_credential
     # @abc.abstractmethod
     def get_credential(
-        self, service, username
+        self,
+        service: str,
+        username: Optional[str],
     ) -> Optional[credentials.SimpleCredential]:
         """Gets the username and password for the service.
         Returns a Credential instance.
@@ -195,15 +195,14 @@ def _load_plugins():
 
     `initialize_func` is optional, but will be invoked if callable.
     """
-    entry_points = metadata.entry_points().get('keyring.backends', [])
-    for ep in entry_points:
+    for ep in metadata.entry_points(group='keyring.backends'):
         try:
             log.debug('Loading %s', ep.name)
             init_func = ep.load()
             if callable(init_func):
                 init_func()
         except Exception:
-            log.exception("Error initializing plugin {ep}.".format(**locals()))
+            log.exception(f"Error initializing plugin {ep}.")
 
 
 @util.once
